// Persistence Of Vision Ray Tracer Scene Description File
// -------------------------------------------------------
// File: @(#)title1.pov
// Desciption: title image for POV KIO slave
// Creation Date: $ 30 May 2004, 21:19:00 $
// Last modified: $ 28 Apr 2005, 18:30:11 $
// Author: Christoph Hormann <chris_hormann@gmx.de>
//
// -w150 -h120 +a0.2 +am2 +ua DECLARE=Variant=1
//

#ifndef (Variant)
	#declare Render_Shadow=false;
	#declare Render_Alpha=false;
	#declare Render_Bkg=false;
#else
	#switch (Variant)
		#case (0) // normal render (for testing)
			#declare Render_Shadow=false;
			#declare Render_Alpha=false;
			#declare Render_Bkg=false;
		#break
		#case (1) // alpha render (for foreground)
			#declare Render_Shadow=false;
			#declare Render_Alpha=true;
			#declare Render_Bkg=false;
		#break
		#case (2) // background render (for shadow color)
			#declare Render_Shadow=false;
			#declare Render_Alpha=false;
			#declare Render_Bkg=true;
		#break
		#case (3) // shadow render (for shadow shape)
			#declare Render_Shadow=true;
			#declare Render_Alpha=false;
			#declare Render_Bkg=false;
		#break
	#end
#end
	
#ifndef (Icon)
	#declare Icon=false;
#end
	
#declare use_hdri=true;
#declare Test_Render=false;

//#version 3.5;
#version unofficial megapov 1.2;

global_settings {
  assumed_gamma 1.0 
  max_trace_level 35
}

global_settings {
  assumed_gamma 1
  max_trace_level 15
	tone_mapping { function { min(1, x) } }

	#if (!Test_Render & !Render_Shadow)
		radiosity{

			pretrace_start 0.08
			pretrace_end   0.01
			count 120

			nearest_count 5
			error_bound 0.4//0.05
			recursion_limit 1

			low_error_factor .5
			gray_threshold 0.0
			minimum_reuse 0.015
			brightness 0.85

			adc_bailout 0.01/2

		}
	#end

}

background { color rgb 1 }
	
camera {
  location  <-1.2, -6.0, 3.5>
  up z
  sky z
  look_at   <-0.15, 0.0, 0.6> 
  right x*(image_width/image_height)
	#if (Icon)
		angle 17
	#else
		angle 22
	#end
}      

light_source {
  <2000, -1600, 2000>*0.5
  color rgb <2.2, 1.8, 1.5>
	#if (!Test_Render | Render_Shadow)
		area_light 100*x 100*y  6, 6 jitter orient circular adaptive 1
	#end
}

#declare Angle=10;

#if (use_hdri)
sphere {
  0,1
  pigment {
    image_map {
			hdr "patio.hdr"
      once
      interpolate 2
      map_type 2
    }
    scale 2 translate -y
  }
  finish {
    ambient 1
    diffuse 0
  }

  scale 2000
  rotate 90*x
  hollow
  rotate Angle*z
	no_image
}
	
#else

sky_sphere {
  pigment {
    gradient z		
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.2 rgb <0.2,0.3,0.9>]
    }
  }
}  

#end
	
// ----------------------------------------
   
plane {
  z, 0.0
  texture { 
		#if (Render_Shadow)
			pigment { color rgb 1 }
			finish { ambient 0.05 diffuse 1.05 }
		#else
			pigment { color rgb <pow(79/255, 2.2), pow(79/255, 2.2), pow(200/255, 2.2)> }
			#if (Render_Bkg)
				finish { ambient 0 diffuse 0.15 }
			#else
				finish { ambient 0 diffuse 0.6 }
			#end
		#end
  }
	#if (Render_Alpha)
		no_image
	#end
}    

#if (Render_Shadow)
	
#declare Tex_Metal=
  texture {
    pigment { color rgb 0 }
  }

#declare Tex_Metal2=
  texture {
    pigment { color rgb 0 }
  }
	
#declare Mat_Glass1=
  material {
    texture {
      pigment { color rgb 0 }
    }
  }
	
#else
	
#declare Tex_Metal=
  texture {
    pigment { color rgb <1.0, 0.6, 0.2> }
    finish{
      diffuse 0.4
      ambient 0.0
      //specular 0.6
			roughness 0.007
      reflection { 0.5 metallic }
			conserve_energy
    }
  }

#declare Tex_Metal2=
  texture {
    //pigment { color rgb <0.1, 0.3, 1.0> }
    pigment { color rgb <0.1, 0.23, 1.0> }
    finish{
      diffuse 1.0
      ambient 0.0
      specular 0.6
        roughness 0.012
      reflection { 0.15 metallic }
			conserve_energy
    }
  }

#include "glass.inc"

#declare Mat_Glass1=
  material {
    texture {
      pigment { color rgbt <0.5, 0.5, 0.75, 0.9> }
      finish {
        reflection { 0.2, 1.0 fresnel on }
        diffuse 0.5
        ambient 0
        specular 0.2
        roughness 0.007
        conserve_energy
      }
    }
    interior {
      I_Glass2
			fade_color Col_Amethyst_03
      fade_distance 0.2
    }
  }
	
#end

// ----------------------------------------


#declare fn_Spline1=
function {
	spline {
		linear_spline  
		-100, < 0.0, 0>, 
		-10, < 0.0, 0>, 
		-0.3, < 0.0, 0>, 
		-0.295, < 0.0, 0.1>,  
		-0.165, < 1.0, 0.9>, 
		-0.16, < 1.0, 1>,  
		-0.14, < 1.0, 1>, 
		-0.12, < 1.0, 1>, 
		-0.10, < 1.0, 1>, 
		-0.08, < 1.0, 1>, 
		-0.06, < 1.0, 1>, 
		 0.06, < 1.0, 1>, 
		 0.08, < 1.0, 1>, 
		 0.10, < 1.0, 1>, 
		 0.12, < 1.0, 1>, 
		 0.14, < 1.0, 1>, 
		 0.16, < 1.0, 1>, 
		 0.165, < 1.0, 0.9>, 
		 0.295, < 0.0, 0.1>, 
		 0.3, < 0.0, 0>, 
		 10, < 0.0, 0> ,      
		 100, < 0.0, 0>  
	}
} 

#include "iso_csg.inc"
#include "shapes.inc"
#include "logo.inc"

#local fn_dents=
function(x) {
	fn_Spline1(x-int(x)-0.5).y
}

#local fn_cyl=
function {
	f_r(x, y, 0)-0.5
	-fn_dents(abs(atan2(x,y)*4/pi))*0.18
}


difference {
	isosurface {		
		function {
			fn_cyl(x,y,z)
		}	
		max_gradient 5		
		contained_by { box { <-1,-1,0.03>,<1,1,0.35> } }
	}
	Round_Cylinder_Merge(<0,0,0.28>, 0.6*z, 0.4, 0.03)
	cylinder { -z, z, 0.1 }
	texture { Tex_Metal2 }
	
	#if (Render_Bkg | Render_Shadow)
		no_image
	#end
}

difference {
	Round_Cylinder_Union(<0,0,0>, 0.3*z, 0.29, 0.03)
	cylinder { -z, z, 0.1 }
	texture { Tex_Metal2 }
	
	#if (Render_Bkg | Render_Shadow)
		no_image
	#end
}

#declare Povray_LogoX =
merge {
   difference {
      cone {2*y, 1, -4*y, 0}
      sphere {2*y, 1.4 scale <1,1,2>}
   }
   difference {
      sphere {0, 1 scale <2.6, 2.2, 1>}
      sphere {0, 1 scale <2.3, 1.8, 2> translate <-0.35, 0, 0>}
      rotate z*30 translate 2*y
   }
   rotate <0, 0, -25>
   translate <-0.5,-0.35,0>
   scale 1/4
}


object {
	Povray_LogoX
	rotate 90*x
	scale 0.75
	translate <0.26,0,0.75>
	
	texture { Tex_Metal }
	
	#if (Render_Bkg | Render_Shadow)
		no_image
	#end
}

sphere {
	2*y, 1
	rotate <0, 0, -25>
	translate <-0.5,-0.35,0>
	scale 1/4
	rotate 90*x
	scale 0.75
	translate <0.26,0,0.75>
	
	material { Mat_Glass1 } 
	
	#if (Render_Bkg | Render_Shadow)
		no_image
	#end
}