/***************************************************************************
 *   Copyright (C) 2004-2005 by Christoph Hormann <chris_hormann@gmx.de>   *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. *
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#ifndef _pov_H_
#define _pov_H_

#define DEBUG_AREA 7130

#define KIO_POV_NAME "kio-pov"
#define KIO_POV_URL "http://www.imagico.de/kiopov/"
#define KIO_POV_VERSION "0.2"

#define KIO_POV_THUMBNAIL_WIDTH 320
#define KIO_POV_THUMBNAIL_HEIGHT 240
#define KIO_POV_MAX_THUMBNAIL_SIZE 1600


#include <kio/slavebase.h>
#include <kio/global.h>
#include <kurl.h>
#include <kprocess.h>

#include <qstring.h>
#include <qcstring.h>
#include <qbitarray.h>

#include "povexe.h"
#include "povscene.h"


class kio_povProtocol : public QObject, public KIO::SlaveBase
{
	Q_OBJECT

	public:
		kio_povProtocol(const QCString &pool_socket, const QCString &app_socket);
		virtual ~kio_povProtocol();
		virtual void mimetype(const KURL& url);
		virtual void get(const KURL& url);

	protected slots:
		void slotSetDataStdOutput(KProcess*, char *s, int len);
		void slotGetStdError(KProcess*, char *s, int len);
		void slotGetStdErrorAnim(KProcess*, char *s, int len);
		void slotMpegStdOut(KProcess*, char *s, int len);

	private:
		QString GenerateInfo(const KURL & url);
		QString HTMLInfoTable(const QStringList & col1, const QStringList & col2);
		bool loadTemplate(const QString& filename, QString& buffer);
		void HTMLMessage(const QString & title, const QString & message);
		QString HTMLLog(const QString & log, const bool Escape);
		QString Find_POV_Include(POVExecutable & Povray, const QString& File, const QString& Scene_Dir);
		int RenderStill(const QByteArray & output_data, POVScene & Scene);
		int RenderAnim(const QByteArray & output_data, POVScene & Scene);
		void GenerateThumbnail(POVScene & Scene);
		int GenerateMpeg(POVScene & Scene, const QByteArray & output_data, const int digits);
		int AnalyzeLog(QString & Error_Message, QString & Error_Text);
		bool FormatLog(const POVScene & Scene, const int Variant);
		bool FormatError(POVScene & Scene, const QString & Error_Message, const QString & Error_Text);
		bool FormatErrorFFMpeg(POVScene & Scene, const QString & Error_Message);
		void ProcessFile(const KURL & url);

		long processedBytes;
		QString ErrorStream;
		QString FFMpegErrorStream;
		QDataStream *Povray_ImageStream;
		KProcess* PovrayKProcess;
		KProcess* ConvertKProcess;
		KProcess* FFMpegKProcess;
};

#endif
